@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2020 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,10 +16,6 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
-import pickle
-import numpy as np
-from hyperspy.misc.utils import stack as stack_method
-
 
 class CalibrationDataLibrary(dict):
     """Maps crystal structure (phase) to diffraction vectors.
@@ -42,7 +38,7 @@ class CalibrationDataLibrary(dict):
         self.moo3_im = moo3_im
 
     def plot_calibration_data(self, data_to_plot, roi=None, *args, **kwargs):
-        """ Plot the calibration data.
+        """Plot the calibration data.
 
         Parameters
         ----------
