@@ -1,37 +1,43 @@
 name = "pyxem"
-version = "0.13.3"
+version = "0.14.0"
 author = "Duncan Johnstone, Phillip Crout, Magnus Nord"
-copyright = "Copyright 2016-2021, The pyxem developers"
+copyright = "Copyright 2016-2022, The pyxem developers"
+# Contributors listed by original commiter, maintainers, then other
+# within groups organised by  number of commits.
+# See: https://github.com/pyxem/pyxem/graphs/contributors
 credits = [
     "Duncan Johnstone",
     "Phillip Crout",
     "Magnus Nord",
+    "Carter Francis",
     "Joonatan Laulainen",
     "Simon Høgås",
     "Eirik Opheim",
     "Ben Martineau",
-    "Carter Francis",
     "Tina Bergh",
     "Eric Prestat",
+    "Niels Cautaerts",
     "Stef Smeets",
     "Andrew Ross",
+    "Joseph Broussard",
+    "Håkon Wiik Ånes",
     "Sean Collins",
     "Tom Furnival",
     "Daen Jannis",
     "Ida Hjorth",
-    "Endre Jacobsen",
     "Mohsen Danaie",
     "Andrew Herzing",
+    "Endre Jacobsen",
     "Tim Poon",
-    "Håkon Wiik Ånes",
     "Tiarnan Doherty",
-    "Affan Iqbal",
+    "Shuoyuan Huang",
     "Jedrzej Morzy",
+    "Affan Iqbal",
     "Tomas Ostasevicius",
-    "Rob Tovey",
     "Matt von Lany",
+    "Rob Tovey",
 ]
 license = "GPLv3"
-maintainer = "Duncan Johnstone, Phillip Crout, Magnus Nord"
+maintainer = "Duncan Johnstone, Phillip Crout, Magnus Nord, Carter Francis"
 email = "pyxem.team@gmail.com"
 status = "development"
