@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2021 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Signal class for two-dimensional diffraction data in Cartesian coordinates."""
+
 
 import numpy as np
 from skimage import filters
@@ -31,12 +31,9 @@ import warnings
 import hyperspy.api as hs
 from hyperspy.signals import Signal2D, BaseSignal
 from hyperspy._signals.lazy import LazySignal
-from hyperspy._signals.signal1d import LazySignal1D
 from hyperspy._signals.signal2d import LazySignal2D
 from hyperspy.misc.utils import isiterable
 
-from pyFAI.units import to_unit
-
 from pyxem.signals import (
     CommonDiffraction,
     DPCBaseSignal,
@@ -55,7 +52,6 @@ from pyxem.utils.expt_utils import (
     azimuthal_integrate1d,
     azimuthal_integrate2d,
     gain_normalise,
-    remove_dead,
     regional_filter,
     circular_mask,
     find_beam_offset_cross_correlation,
@@ -68,7 +64,6 @@ from pyxem.utils.expt_utils import (
     sigma_clip,
 )
 from pyxem.utils.dask_tools import (
-    _process_dask_array,
     _get_dask_array,
     get_signal_dimension_host_chunk_slice,
     align_single_frame,
@@ -84,6 +79,8 @@ import pyxem.utils.ransac_ellipse_tools as ret
 
 
 class Diffraction2D(Signal2D, CommonDiffraction):
+    """Signal class for two-dimensional diffraction data in Cartesian coordinates."""
+
     _signal_type = "diffraction"
 
     """ Methods that make geometrical changes to a diffraction pattern """
@@ -249,7 +246,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             show_progressbar=show_progressbar,
         )
         if self._lazy:
-            s_rotated.compute(progressbar=show_progressbar)
+            s_rotated.compute(show_progressbar=show_progressbar)
         return s_rotated
 
     def flip_diffraction_x(self):
@@ -489,7 +486,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         )
         s_dead_pixels = LazySignal2D(dead_pixels)
         if not lazy_result:
-            s_dead_pixels.compute(progressbar=show_progressbar)
+            s_dead_pixels.compute(show_progressbar=show_progressbar)
         return s_dead_pixels
 
     def find_hot_pixels(
@@ -553,7 +550,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
 
         s_hot_pixels = LazySignal2D(hot_pixels)
         if not lazy_result:
-            s_hot_pixels.compute(progressbar=show_progressbar)
+            s_hot_pixels.compute(show_progressbar=show_progressbar)
         return s_hot_pixels
 
     def correct_bad_pixels(
@@ -605,12 +602,12 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         s_bad_pixel_removed = LazyDiffraction2D(bad_pixel_removed)
         pst._copy_signal2d_axes_manager_metadata(self, s_bad_pixel_removed)
         if not lazy_result:
-            s_bad_pixel_removed.compute(progressbar=show_progressbar)
+            s_bad_pixel_removed.compute(show_progressbar=show_progressbar)
         return s_bad_pixel_removed
 
     """ Direct beam and peak finding tools """
 
-    def get_direct_beam_position(self, method, lazy_result=None, **kwargs):
+    def get_direct_beam_position(self, method, lazy_output=None, **kwargs):
         """Estimate the direct beam position in each experimentally acquired
         electron diffraction pattern.
 
@@ -631,8 +628,13 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             signal index being the x-shift and the second the y-shift.
 
         """
-        if lazy_result is None:
-            lazy_result = self._lazy
+        if "lazy_result" in kwargs:
+            warnings.warn("lazy_result was replaced with lazy_output in version 0.14",
+                          DeprecationWarning)
+            lazy_output = kwargs.pop("lazy_result")
+
+        if lazy_output is None:
+            lazy_output = self._lazy
 
         signal_shape = self.axes_manager.signal_shape
         origin_coordinates = np.array(signal_shape) / 2
@@ -643,56 +645,39 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             "interpolate": find_beam_center_interpolate,
         }
 
-        method_function = select_method_from_method_dict(method, method_dict, **kwargs)
-
-        dask_array = _get_dask_array(self)
-
-        drop_axis = (len(self.axes_manager.shape) - 2, len(self.axes_manager.shape) - 1)
-        new_axis = self.axes_manager.navigation_dimension
-        chunks_output = dask_array.chunks[:-2] + ((2,),)
+        method_function = select_method_from_method_dict(method, method_dict,
+                                                         print_help=False, **kwargs)
 
         if method == "cross_correlate":
-            shifts = _process_dask_array(
-                dask_array,
-                method_function,
-                dtype=np.float32,
-                output_signal_size=(2,),
-                drop_axis=drop_axis,
-                new_axis=new_axis,
-                chunks=chunks_output,
-                **kwargs,
-            )
+            shifts = self.map(method_function,
+                              inplace=False,
+                              output_signal_size=(2,),
+                              output_dtype=np.float32,
+                              lazy_output=lazy_output,
+                              **kwargs,
+                              )
         elif method == "blur":
-            centers = _process_dask_array(
-                dask_array,
-                method_function,
-                dtype=np.int16,
-                output_signal_size=(2,),
-                drop_axis=drop_axis,
-                new_axis=new_axis,
-                chunks=chunks_output,
-                **kwargs,
-            )
-            shifts = origin_coordinates - centers
+            centers = self.map(method_function,
+                               inplace=False,
+                               output_signal_size=(2,),
+                               output_dtype=np.int16,
+                               lazy_output=lazy_output,
+                               **kwargs,
+                               )
+            shifts = -centers + origin_coordinates
         elif method == "interpolate":
-            centers = _process_dask_array(
-                dask_array,
-                method_function,
-                dtype=np.float32,
-                output_signal_size=(2,),
-                drop_axis=drop_axis,
-                new_axis=new_axis,
-                chunks=chunks_output,
-                **kwargs,
-            )
-            shifts = origin_coordinates - centers
+            centers = self.map(method_function,
+                               inplace=False,
+                               output_signal_size=(2,),
+                               output_dtype=np.float32,
+                               lazy_output=lazy_output,
+                               **kwargs,
+                               )
+            shifts = -centers + origin_coordinates
 
-        s_shifts = LazySignal1D(shifts)
+        shifts.set_signal_type("beam_shift")
 
-        if not lazy_result:
-            s_shifts.compute()
-
-        return s_shifts
+        return shifts
 
     def center_direct_beam(
         self,
@@ -701,8 +686,9 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         shifts=None,
         return_shifts=False,
         subpixel=True,
-        lazy_result=None,
+        lazy_output=None,
         align_kwargs=None,
+        inplace= True,
         *args,
         **kwargs,
     ):
@@ -759,6 +745,10 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         use a float dtype, which can be done by s.change_dtype('float32', rechunk=False).
 
         """
+        if "lazy_result" in kwargs:
+            warnings.warn("lazy_result was replaced with lazy_output in version 0.14",
+                          DeprecationWarning)
+            lazy_output = kwargs.pop("lazy_result")
         if (shifts is None) and (method is None):
             raise ValueError("Either method or shifts parameter must be specified")
         if (shifts is not None) and (method is not None):
@@ -766,30 +756,22 @@ class Diffraction2D(Signal2D, CommonDiffraction):
                 "Only one of the shifts or method parameters should be specified, "
                 "not both"
             )
-        if lazy_result is None:
-            lazy_result = self._lazy
         if align_kwargs is None:
             align_kwargs = {}
 
         signal_shape = self.axes_manager.signal_shape
         origin_coordinates = np.array(signal_shape) / 2
-
-        data_dask_array = _get_dask_array(self)
-        if not self._lazy:
-            temp_signal = self.as_lazy()
-            temp_signal.data = da.from_array(self.data, chunks=data_dask_array.chunks)
-        else:
-            temp_signal = self
+        temp_signal = self
 
         if shifts is None:
             if half_square_width is not None:
-                min_index = np.int(origin_coordinates[0] - half_square_width)
+                min_index = int(origin_coordinates[0] - half_square_width)
                 # fails if non-square dp
-                max_index = np.int(origin_coordinates[0] + half_square_width)
+                max_index = int(origin_coordinates[0] + half_square_width)
                 temp_signal = temp_signal.isig[min_index:max_index, min_index:max_index]
             shifts = temp_signal.get_direct_beam_position(
                 method=method,
-                lazy_result=True,
+                lazy_output=lazy_output,
                 **kwargs,
             )
 
@@ -798,43 +780,21 @@ class Diffraction2D(Signal2D, CommonDiffraction):
                 align_kwargs["order"] = 1
             else:
                 align_kwargs["order"] = 0
+        aligned = self.map(align_single_frame,
+                           shifts=shifts,
+                           inplace=inplace,
+                           lazy_output=lazy_output,
+                           output_dtype=self.data.dtype,
+                           output_signal_size=self.axes_manager.signal_shape[::-1],
+                           **align_kwargs)
 
-        shifts_dask_array = _get_dask_array(shifts)
 
-        output_dask_array = _process_dask_array(
-            data_dask_array,
-            align_single_frame,
-            iter_array=shifts_dask_array,
-            **align_kwargs,
-        )
-
-        if lazy_result:
-            if not self._lazy:
-                self._lazy = True
-                self._assign_subclass()
-            self.data = output_dask_array
-        else:
-            if self._lazy:
-                self.data = np.empty(
-                    output_dask_array.shape, dtype=output_dask_array.dtype
-                )
-                self._lazy = False
-                self._assign_subclass()
-            shifts.data = np.empty(
-                shifts_dask_array.shape, dtype=shifts_dask_array.dtype
-            )
-            shifts._lazy = False
-            shifts._assign_subclass()
-            with ProgressBar():
-                da.store(
-                    [shifts_dask_array, output_dask_array],
-                    [shifts.data, self.data],
-                )
-
-        self.events.data_changed.trigger(obj=self)
-
-        if return_shifts:
+        if return_shifts and inplace:
             return shifts
+        elif return_shifts:
+            return shifts, aligned
+        else:
+            return aligned
 
     def threshold_and_mask(self, threshold=None, mask=None, show_progressbar=True):
         """Get a thresholded and masked of the signal.
@@ -937,7 +897,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         Get a lazy signal, then calculate afterwards
 
         >>> s_com = s.center_of_mass(lazy_result=True, show_progressbar=False)
-        >>> s_com.compute(progressbar=False)
+        >>> s_com.compute(show_progressbar=False)
 
         """
         det_shape = self.axes_manager.signal_shape
@@ -1141,7 +1101,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         show_progressbar : bool, optional
             Default True
         **kwargs :
-            Passed to the peakfinder, see skimage docs for details
+            Passed to the peakfinder, see skimage doc for details
 
         Returns
         -------
@@ -1470,104 +1430,6 @@ class Diffraction2D(Signal2D, CommonDiffraction):
 
         mt._add_permanent_markers_to_signal(self, marker_list)
 
-    def lazy_virtual_bright_field(
-        self, cx=None, cy=None, r=None, lazy_result=False, show_progressbar=True
-    ):
-        """Get a virtual bright field signal.
-
-        Can be sum the whole diffraction plane, or a circle subset.
-        If any of the parameters are None, it will sum the whole diffraction
-        plane.
-
-        Parameters
-        ----------
-        cx, cy : floats, optional
-            x- and y-centre positions.
-        r : float, optional
-            Outer radius.
-        lazy_result : bool, optional
-            If True, will not compute the data directly, but
-            return a lazy signal. Default False
-        show_progressbar : bool, optional
-            Default True.
-
-        Returns
-        -------
-        virtual_bf_signal : HyperSpy 2D signal
-
-        See Also
-        --------
-        get_integrated_intensity
-        """
-        warnings.warn("This method is depreacted and will be removed in the next version",FutureWarning)
-        det_shape = self.axes_manager.signal_shape
-        if (cx is None) or (cy is None) or (r is None):
-            mask_array = np.zeros(det_shape[::-1], dtype=bool)
-        else:
-            mask_array = pst._make_circular_mask(cx, cy, det_shape[0], det_shape[1], r)
-            mask_array = np.invert(mask_array)
-        data = dt._mask_array(self.data, mask_array=mask_array).sum(axis=(-2, -1))
-        s_bf = LazySignal2D(data)
-        if not lazy_result:
-            s_bf.compute(progressbar=show_progressbar)
-        for nav_axes, sig_axes in zip(
-            self.axes_manager.navigation_axes, s_bf.axes_manager.signal_axes
-        ):
-            pst._copy_axes_object_metadata(nav_axes, sig_axes)
-
-        return s_bf
-
-    def lazy_virtual_annular_dark_field(
-        self, cx, cy, r_inner, r, lazy_result=False, show_progressbar=True
-    ):
-        """Get a virtual annular dark field signal.
-
-        Parameters
-        ----------
-        cx, cy : floats
-            x- and y-centre positions.
-        r_inner : float
-            Inner radius.
-        r : float
-            Outer radius.
-        lazy_result : bool, optional
-            If True, will not compute the data directly, but
-            return a lazy signal. Default False
-        show_progressbar : bool, default True
-
-        Returns
-        -------
-        virtual_adf_signal : HyperSpy 2D signal
-
-        See Also
-        --------
-        get_integrated_intensity
-        """
-        warnings.warn("This method is depreacted and will be removed in the next version",FutureWarning)
-
-        if r_inner > r:
-            raise ValueError(
-                "r_inner must be higher than r. The argument order is "
-                + "(cx, cy, r_inner, r)"
-            )
-        det_shape = self.axes_manager.signal_shape
-
-        mask_array0 = pst._make_circular_mask(cx, cy, det_shape[0], det_shape[1], r)
-        mask_array1 = pst._make_circular_mask(
-            cx, cy, det_shape[0], det_shape[1], r_inner
-        )
-        mask_array = mask_array0 == mask_array1
-
-        data = dt._mask_array(self.data, mask_array=mask_array).sum(axis=(-2, -1))
-        s_adf = LazySignal2D(data)
-        if not lazy_result:
-            s_adf.compute(progressbar=show_progressbar)
-        for nav_axes, sig_axes in zip(
-            self.axes_manager.navigation_axes, s_adf.axes_manager.signal_axes
-        ):
-            pst._copy_axes_object_metadata(nav_axes, sig_axes)
-        return s_adf
-
     def angular_mask(self, angle0, angle1, centre_x_array=None, centre_y_array=None):
         """Get a bool array with True values between angle0 and angle1.
         Will use the (0, 0) point as given by the signal as the centre,
@@ -1616,7 +1478,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         navigation_axes=None,
         **kwargs,
     ):
-        """Calculates the variance using one of the methods described in [1]. A shot noise correction and
+        """Calculates the variance using one of the methods described in [1]. A shot noise correction
            and specification of axes to operate over are also possible.
 
         Parameters
@@ -1628,7 +1490,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         dqe : int, optional
             The detector quantum efficiency or the pixel value for one electron.
         spatial : bool, optional
-            Included intermediate spatial variance in output (only avaliable if method=='r')
+            Included intermediate spatial variance in output (only available if method=='r')
         navigation_axes : list or none, optional
             The axes to calculate the variance over.  The default is to use the navigation axes.
         **kwargs: dict
@@ -1765,7 +1627,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
 
         """
         warnings.warn(
-            "This method is depreacted, and will be removed in version 0.14.0, please use .get_azimuthal_integral1d",
+            "This method is deprecated, and will be removed in version 0.14.0, please use .get_azimuthal_integral1d",
             FutureWarning,
         )
         if (centre_x is None) or (centre_y is None):
@@ -1785,37 +1647,39 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             )
             + 1
         )
-        centre_x = centre_x.flatten()
-        centre_y = centre_y.flatten()
-        iterating_kwargs = [("centre_x", centre_x), ("centre_y", centre_y)]
-        if mask_array is not None:
-            #  This line flattens the mask array, except for the two
-            #  last dimensions. This to make the mask array work for the
-            #  _map_iterate function.
-            mask_flat = mask_array.reshape(-1, *mask_array.shape[-2:])
-            iterating_kwargs.append(("mask", mask_flat))
-
         if self._lazy:
             data = pst._radial_average_dask_array(
                 self.data,
                 return_sig_size=radial_array_size,
-                centre_x=centre_x,
-                centre_y=centre_y,
+                centre_x=centre_x.flatten(),
+                centre_y=centre_y.flatten(),
                 mask_array=mask_array,
                 normalize=normalize,
                 show_progressbar=show_progressbar,
             )
             s_radial = hs.signals.Signal1D(data)
         else:
-            s_radial = self._map_iterate(
+            if mask_array is not None:
+                mask_array = Signal2D(mask_array)
+            if self.data.ndim == centre_x.ndim:
+                centre_x = Signal2D(centre_x)
+                centre_y = Signal2D(centre_y)
+            else:
+                centre_x = BaseSignal(centre_x).T
+                centre_y = BaseSignal(centre_y).T
+
+            s_radial = self.map(
                 pst._get_radial_profile_of_diff_image,
                 normalize=normalize,
-                iterating_kwargs=iterating_kwargs,
+                centre_x=centre_x,
+                centre_y=centre_y,
+                mask=mask_array,
                 inplace=False,
                 ragged=False,
                 parallel=parallel,
                 radial_array_size=radial_array_size,
                 show_progressbar=show_progressbar,
+                lazy_output=False,
             )
             data = s_radial.data
         s_radial = hs.signals.Signal1D(data)
@@ -1987,12 +1851,9 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         mask=None,
         radial_range=None,
         azimuth_range=None,
-        wavelength=None,
         inplace=False,
         method="splitpixel",
         sum=False,
-        lazy_result=None,
-        show_progressbar=None,
         **kwargs,
     ):
         """Creates a polar reprojection using pyFAI's azimuthal integrate 2d. This method is designed
@@ -2013,9 +1874,6 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         azimuth_range : None or (float, float)
             The azimuthal range over which to perform the integration. Default is
             from -pi to pi
-        wavelength : None or float
-            The wavelength of for the microscope. Has to be in the same units as the pyxem units if you want
-            it to properly work.
         inplace : bool
             If the signal is overwritten or copied to a new signal
         method : str
@@ -2025,13 +1883,6 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         sum : bool
             If true returns the pixel split sum rather than the azimuthal integration which
             gives the mean.
-        lazy_result : optional
-            If True, the result will be a lazy signal. If False, a non-lazy signal.
-            By default, if the signal is lazy, the result will also be lazy.
-            If the signal is non-lazy, the result will be non-lazy.
-        show_progressbar : None or bool
-            If True and lazy_result is True, show a progressbar for the calculation.
-            If None, the preference from the settings will be used.
 
         Other Parameters
         -------
@@ -2064,67 +1915,48 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         (wavelength needed)
 
         >>> ds.unit = "k_nm^-1" # setting units
-        >>> ds.get_azimuthal_integral1d(npt=100, wavelength=2.5e-12)
+        >>> ds.set_ai(wavelength=2.5e-12) # creating an AzimuthalIntegrator Object
+        >>> ds.get_azimuthal_integral1d(npt=100)
 
-        Using pyFAI to define a detector case using a curved Ewald Sphere approximation and pyXEM units
-
-        >>> from pyFAI.detectors import Detector
-        >>> det = Detector(pixel1=1e-4, pixel2=1e-4)
-        >>> ds.get_azimuthal_integral1d(npt=100, detector_dist=.2, detector= det, wavelength=2.508e-12)
         """
-        if lazy_result is None:
-            lazy_result = self._lazy
-        signal_type = self._signal_type
-        unit = to_unit(self.unit)
+        if "lazy_result" in kwargs:
+            warnings.warn("lazy_result was replaced with lazy_output in version 0.14",
+                          DeprecationWarning)
+            kwargs["lazy_output"] = kwargs.pop("lazy_result")
+        if "wavelength" in kwargs:
+            warnings.warn("The wavelength parameter was removed in 0.14. The wavelength "
+                          "can be set using the `set_ai` function or using `s.beam_energy`"
+                          " for `ElectronDiffraction2D` signals")
+            kwargs.pop("wavelength")
+
         sig_shape = self.axes_manager.signal_shape
         if radial_range is None:
-            radial_range = _get_radial_extent(ai=self.ai, shape=sig_shape, unit=unit)
+            radial_range = _get_radial_extent(
+                ai=self.ai, shape=sig_shape, unit=self.unit
+            )
             radial_range[0] = 0
-
-        data_dask_array = _get_dask_array(self)
-        chunks = data_dask_array.chunks[:-2] + ((npt,),)
-        drop_axis = (len(self.axes_manager.shape) - 2, len(self.axes_manager.shape) - 1)
-        new_axis = self.axes_manager.navigation_dimension
-        integration_dask_array = _process_dask_array(
-            data_dask_array,
+        integration = self.map(
             azimuthal_integrate1d,
-            drop_axis=drop_axis,
-            new_axis=new_axis,
-            chunks=chunks,
-            output_signal_size=(npt,),
             azimuthal_integrator=self.ai,
             npt_rad=npt,
             azimuth_range=azimuth_range,
             radial_range=radial_range,
             method=method,
-            unit=unit,
+            inplace=inplace,
+            unit=self.unit,
+            mask=mask,
             sum=sum,
-            dtype=np.float32,  # pyFAI does the calculation in float32
             **kwargs,
         )
+        s = self if inplace else integration
 
         # Dealing with axis changes
-        if inplace:
-            result = self
-            result.axes_manager.remove(self.axes_manager.signal_axes[0])
-            result.data = integration_dask_array
-            result._lazy = True
-        else:
-            result = LazySignal1D(integration_dask_array)
-            result.set_signal_type(signal_type)
-            transfer_navigation_axes(result, self)
-        k_axis = result.axes_manager.signal_axes[0]
+        k_axis = s.axes_manager.signal_axes[0]
         k_axis.name = "Radius"
         k_axis.scale = (radial_range[1] - radial_range[0]) / npt
-        k_axis.units = unit.unit_symbol
         k_axis.offset = radial_range[0]
-
-        result.set_signal_type(signal_type)
-        if not lazy_result:
-            result.compute(show_progressbar=show_progressbar)
-
-        if not inplace:
-            return result
+        
+        return integration
 
     def get_azimuthal_integral2d(
         self,
@@ -2152,7 +1984,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             The number of azimuthal points to calculate
         mask:  boolean array or BaseSignal
             A boolean mask to apply to the data to exclude some points.
-            If mask is a baseSignal then it is itereated over as well.
+            If mask is a BaseSignal then it is iterated over as well.
         radial_range: None or (float, float)
             The radial range over which to perform the integration. Default is
             the full frame
@@ -2194,7 +2026,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         Returns
         -------
         polar: PolarDiffraction2D
-            A polar diffraction signal
+            A polar diffraction signal, when inplace is False, otherwise None
 
         Examples
         --------
@@ -2207,16 +2039,11 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         (wavelength needed)
 
         >>> ds.unit = "k_nm^-1" # setting units
-        >>> ds.get_azimuthal_integral2d(npt_rad=100, wavelength=2.5e-12)
+        >>> ds.set_ai(wavelength=2.5e-12)
+        >>> ds.get_azimuthal_integral2d(npt_rad=100)
 
-        Using pyFAI to define a detector case using a curved Ewald Sphere approximation and pyXEM units
-
-        >>> from pyFAI.detectors import Detector
-        >>> det = Detector(pixel1=1e-4, pixel2=1e-4)
-        >>> ds.get_azimuthal_integral2d(npt_rad=100, detector_dist=.2, detector= det, wavelength=2.508e-12)
         """
         sig_shape = self.axes_manager.signal_shape
-        unit = self.unit
         if radial_range is None:
             radial_range = _get_radial_extent(
                 ai=self.ai, shape=sig_shape, unit=self.unit
@@ -2238,26 +2065,24 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             **kwargs,
         )
 
+        s = self if inplace else integration
+        s.set_signal_type("polar_diffraction")
+
         # Dealing with axis changes
-        if inplace:
-            t_axis = self.axes_manager.signal_axes[0]
-            k_axis = self.axes_manager.signal_axes[1]
-            self.set_signal_type("polar_diffraction")
-        else:
-            transfer_navigation_axes(integration, self)
-            integration.set_signal_type("polar_diffraction")
-            t_axis = integration.axes_manager.signal_axes[0]
-            k_axis = integration.axes_manager.signal_axes[1]
+        t_axis = s.axes_manager.signal_axes[0]
+        k_axis = s.axes_manager.signal_axes[1]
         t_axis.name = "Radians"
+        t_axis.units = "Rad"
+
         if azimuth_range is None:
             t_axis.scale = np.pi * 2 / npt_azim
             t_axis.offset = -np.pi
         else:
             t_axis.scale = (azimuth_range[1] - azimuth_range[0]) / npt
             t_axis.offset = azimuth_range[0]
+
         k_axis.name = "Radius"
         k_axis.scale = (radial_range[1] - radial_range[0]) / npt
-        k_axis.units = unit
         k_axis.offset = radial_range[0]
 
         return integration
@@ -2285,7 +2110,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             number of points in the radial space. Too few points may lead to huge rounding errors.
         mask:  boolean array or BaseSignal
             A boolean mask to apply to the data to exclude some points.
-            If mask is a baseSignal then it is itereated over as well.
+            If mask is a BaseSignal then it is iterated over as well.
         radial_range: None or (float, float)
             The radial range over which to perform the integration. Default is
             the full frame
@@ -2320,7 +2145,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         show_progressbar: bool
             If True shows a progress bar for the mapping function
         parallel: bool
-            If true launches paralell workers for the integration
+            If true launches parallel workers for the integration
         max_workers: int
             The number of streams to initialize. Only used if parallel=True
 
@@ -2345,7 +2170,6 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         >>> ds.get_radial_integral(npt=100,npt_rad=400)
 
         """
-        signal_type = self._signal_type
         sig_shape = self.axes_manager.signal_shape
         if radial_range is None:
             radial_range = _get_radial_extent(
@@ -2368,17 +2192,12 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             **kwargs,
         )
 
+        s = self if inplace else integration
+
         # Dealing with axis changes
-        if inplace:
-            k_axis = self.axes_manager.signal_axes[0]
-            self.set_signal_type(signal_type)
-        else:
-            integration.set_signal_type(signal_type)
-            transfer_navigation_axes(integration, self)
-            k_axis = integration.axes_manager.signal_axes[0]
+        k_axis = s.axes_manager.signal_axes[0]
         k_axis.name = "Radius"
         k_axis.scale = (radial_range[1] - radial_range[0]) / npt
-        # k_axis.units = unit.unit_symbol
         k_axis.offset = radial_range[0]
 
         return integration
@@ -2404,7 +2223,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
              The number of radial points
         mask:  boolean array or BaseSignal
             A boolean mask to apply to the data to exclude some points.
-            If mask is a baseSignal then it is itereated over as well.
+            If mask is a BaseSignal then it is iterated over as well.
         inplace: bool
             If the signal is overwritten or copied to a new signal
         method: str
@@ -2433,7 +2252,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         show_progressbar: bool
             If True shows a progress bar for the mapping function
         parallel: bool
-            If true launches paralell workers for the integration
+            If true launches parallel workers for the integration
         max_workers: int
             The number of streams to initialize. Only used if parallel=True
 
@@ -2458,7 +2277,6 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         >>> ds.get_radial_integral(npt=100,npt_rad=400)
 
         """
-        signal_type = self._signal_type
         sig_shape = self.axes_manager.signal_shape
         radial_range = _get_radial_extent(ai=self.ai, shape=sig_shape, unit=self.unit)
         radial_range[0] = 0
@@ -2475,14 +2293,10 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             **kwargs,
         )
 
+        s = self if inplace else integration
+
         # Dealing with axis changes
-        if inplace:
-            k_axis = self.axes_manager.signal_axes[0]
-            self.set_signal_type(signal_type)
-        else:
-            integration.set_signal_type(signal_type)
-            transfer_navigation_axes(integration, self)
-            k_axis = integration.axes_manager.signal_axes[0]
+        k_axis = s.axes_manager.signal_axes[0]
         k_axis.name = "Radius"
         k_axis.scale = (radial_range[1] - radial_range[0]) / npt_rad
         # k_axis.units = unit.unit_symbol
@@ -2514,7 +2328,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
              The number of radial points
         mask:  boolean array or BaseSignal
             A boolean mask to apply to the data to exclude some points.
-            If mask is a baseSignal then it is itereated over as well.
+            If mask is a BaseSignal then it is iterated over as well.
         inplace: bool
             If the signal is overwritten or copied to a new signal
         method: str
@@ -2543,7 +2357,7 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         show_progressbar: bool
             If True shows a progress bar for the mapping function
         parallel: bool
-            If true launches paralell workers for the integration
+            If true launches parallel workers for the integration
         max_workers: int
             The number of streams to initialize. Only used if parallel=True
 
@@ -2568,7 +2382,6 @@ class Diffraction2D(Signal2D, CommonDiffraction):
         >>> ds.get_radial_integral(npt=100,npt_rad=400)
 
         """
-        signal_type = self._signal_type
         sig_shape = self.axes_manager.signal_shape
         radial_range = _get_radial_extent(ai=self.ai, shape=sig_shape, unit=self.unit)
         radial_range[0] = 0
@@ -2587,14 +2400,10 @@ class Diffraction2D(Signal2D, CommonDiffraction):
             **kwargs,
         )
 
+        s = self if inplace else integration
+
         # Dealing with axis changes
-        if inplace:
-            k_axis = self.axes_manager.signal_axes[0]
-            self.set_signal_type(signal_type)
-        else:
-            integration.set_signal_type(signal_type)
-            transfer_navigation_axes(integration, self)
-            k_axis = integration.axes_manager.signal_axes[0]
+        k_axis = s.axes_manager.signal_axes[0]
         k_axis.name = "Radius"
         k_axis.scale = (radial_range[1] - radial_range[0]) / npt_rad
         # k_axis.units = unit.unit_symbol
