@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright 2016-2021 The pyXem developers
+# Copyright 2016-2022 The pyXem developers
 #
 # This file is part of pyXem.
 #
@@ -16,7 +16,7 @@
 # You should have received a copy of the GNU General Public License
 # along with pyXem.  If not, see <http://www.gnu.org/licenses/>.
 
-"""Signal class for two-dimensional diffraction data in polar coordinates."""
+
 
 from hyperspy.signals import Signal2D
 from hyperspy._signals.lazy import LazySignal
@@ -26,6 +26,7 @@ from hyperspy.drawing.utils import plot_images
 
 
 class Power2D(Signal2D):
+    """Signal class for the power spectrum of some Correlation"""
     _signal_type = "power"
 
     def __init__(self, *args, **kwargs):
@@ -81,7 +82,7 @@ class Power2D(Signal2D):
         return sym_map
 
     def plot_symmetries(self, k_region=None, symmetry=None, *args, **kwargs):
-        """Plots the symmetries in the list of symmetries. Plot symmetries takes all of the arguements that imshow does.
+        """Plots the symmetries in the list of symmetries. Plot symmetries takes all of the arguments that imshow does.
 
         Parameters
         ----------
